@@ -1,4 +1,4 @@
-__version__ = '0.6.0'
+__version__ = '0.7.0'
 
 import os
 import sys
@@ -8,5 +8,5 @@ ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 runtime = None
 
 if 'pytest' not in sys.modules:
-    from omnipy.config.runtime import Runtime
+    from omnipy.hub.runtime import Runtime
     runtime = Runtime()
