@@ -28,9 +28,8 @@ class ParamsFuncJobBaseMixin:
     def param_key_map(self) -> MappingProxyType[str, str]:
         return MappingProxyType(self._param_key_mapper.key_map)
 
+    def _call_job(self, *args: object, **kwargs: object) -> object:
 
-class ParamsFuncJobMixin:
-    def __call__(self, *args: object, **kwargs: object) -> object:
         mapped_fixed_params = self._param_key_mapper.delete_matching_keys(
             self._fixed_params, inverse=True)
         mapped_kwargs = self._param_key_mapper.map_matching_keys_delete_inverse_matches_keep_rest(
@@ -40,7 +39,7 @@ class ParamsFuncJobMixin:
                 raise TypeError('Keyword arguments {} matches parameter key map inversely.'.format(
                     tuple(set(kwargs.keys()) - set(mapped_kwargs.keys()))))
 
-            result = super().__call__(*args, **mapped_fixed_params, **mapped_kwargs)
+            result = super()._call_job(*args, **mapped_fixed_params, **mapped_kwargs)
 
         except TypeError as e:
             if not str(e).startswith('Incorrect job function arguments'):
